@@ -177,18 +177,25 @@ class CM15(DEVusb):
         #evt = [93, 41, 36, 43, 132, 123, 117, 128, 93, 41, 36, 43, 132, 123, 117, 128, 93, 41, 36, 43, 132, 123, 117, 128, 93, 41, 36, 43, 132, 123, 117, 128]
         if not evt:
             return None
-        event = ["0x%02x" % i for i in evt]
         if len(evt) < minlen:
             logger.warning("Event %s lenght shorter than min size (%s), omitting this read",repr(evt),minlen)
             return None
         if evt[0] not in (0x5A,0x5D):
             logger.warning("Event other than PL or RF, omitting this read %s",repr(evt))
             return None
-        if evt[0] == 0x5D:
-            n = evt.count(evt[0])
-            if n > 1:
-                 nb = len(evt) / n
-                 if n * nb == len(evt):
-                      logger.warning("Cut down event %s",repr(evt))
-                      event = ["0x%02x" % i for i in evt[0:nb]]
-        return " ".join(event)
+        if evt[0] == 0x5A:
+            return " ".join(["0x%02x" % i for i in evt])
+        # evt[0] == 0x5D:
+        n = evt.count(evt[0])
+        if n == 1:
+            return " ".join(["0x%02x" % i for i in evt])
+        events = []
+        for i in range(0,n-1):
+            event = evt[0:evt[1:].index(0x5D)+1]
+            if event not in events:
+                events.append(event)
+            del evt[0:evt[1:].index(0x5D)+1]
+        evts = []
+        for e in events:
+            evts.append(" ".join(["0x%02x" % i for i in e]))
+        return '|'.join(evts)
